# Generated by Django 3.2.22 on 2024-01-13 20:08

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("NEMO_publications", "0002_publicationmetadata_month"),
    ]

    operations = [
        migrations.AddField(
            model_name="publicationmetadata",
            name="decision_time",
            field=models.DateTimeField(
                blank=True,
                help_text="The date and time when the publication metadata was approved or rejected.",
                null=True,
            ),
        ),
        migrations.AddField(
            model_name="publicationmetadata",
            name="json_metadata",
            field=models.TextField(blank=True, help_text="Publication json metadata.", null=True),
        ),
        migrations.AddField(
            model_name="publicationmetadata",
            name="status",
            field=models.IntegerField(
                blank=True,
                choices=[(1, "Approved"), (2, "Rejected")],
                help_text="Publication metadata status.",
                null=True,
            ),
        ),
    ]
