# Generated by Django 4.2.23 on 2025-09-19 22:22

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("NEMO_publications", "0005_userpublicationstatus"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="userpublicationstatus",
            options={"verbose_name_plural": "User publication statuses"},
        ),
    ]
