# Generated by Django 4.2.19 on 2025-05-23 13:21

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ("NEMO_publications", "0004_publicationmetadata_image_url"),
    ]

    operations = [
        migrations.CreateModel(
            name="UserPublicationStatus",
            fields=[
                ("id", models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID")),
                ("doi", models.CharField(max_length=255)),
                ("date_added", models.DateTimeField(auto_now_add=True)),
                (
                    "status",
                    models.PositiveIntegerField(choices=[(1, "Pending"), (2, "Added"), (3, "Rejected")], default=1),
                ),
                (
                    "user",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="publication_statuses",
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
            ],
            options={
                "unique_together": {("user", "doi")},
            },
        ),
    ]
