# Generated by Django 3.2.22 on 2024-06-01 14:02

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("NEMO_publications", "0003_publicationmetadata_status_and_json"),
    ]

    operations = [
        migrations.AddField(
            model_name="publicationmetadata",
            name="image_url",
            field=models.URLField(blank=True, help_text="Publication image URL.", null=True),
        ),
    ]
