DEFAULT_PUBLICATION_SETTINGS = {
    "timeout": 15,
    "doi_search_url": "http://dx.doi.org/{}",
    "headers": [{"Accept": "application/x-bibtex"}, {"Accept": "text/bibliography; style=bibtex"}],
}

PUBLICATIONS_SETTINGS = {}
